# Basic Modes of Operation

## 1. Stop after sweep mode (p.35f)
When the MCS8A is armed it waits for a START input signal. When one occurs the sweep is started /
triggered, meaning the time starts to count. Now the arrival times of the STOP input signals relative to the
start are acquired on all channels that are enabled. A STOP event can be either a falling or a rising edge or
both. Even further signals into the START input can be acquired. Since the type of edge is detected and
marked in the acquired data even Time-over-Threshold or pulse width measurements can be accomplished.

The data acquisition can be ended after a given time via the Time preset. In the edit field Range the length
of the spectrum can be entered. A Bin width of 1 means the highest time resolution. The Bin width can be
chosen in powers of 2 up to 1677216 times the elementary dwell time. If an Acq. Delay is specified, data are
acquired in a sweep not before the specified time. Hold after sweep allows to wait a specified time after a
sweep before the next sweep can be started.

### 1.1. Start of measurement
#### 1.1.1. Endless mode (p.44)
mode of the measurement can be endless if the corresponding checkbox is crossed (in settings)
#### 1.1.2. Software start (p.44)
Doesn't require a start signal (checkbox in settings dialogue)

### 1.2. Termination of measurement
terminated by any of the preset (2) conditions
#### 1.2.1. Time preset (total acquisition time) - THIS
in steps of 2.56 ns - total measurement time (in the document: "sweep and so the data acquisition ends after that time" but with sweep preset you can get multiple sweeps. So this is more like a total measurement time)
#### 1.2.2. Sweep preset (number of sweeps)- THIS
+ 48-bit sweep counter counts the real start of a new sweep rather than the completion of the sweeps
+ preset enabled: after preselected number of sweeps any further start of a sweep is prohibited
#### 1.2.3. ROI preset (number of counts) - THIS
Stop measurement after certain number of counts. ROI Preset
### 1.3. Single sweep settings
#### 1.3.1. Acquisiton delay (counting delay after START) - THIS
in steps of 2.56 ns - accept only STOP events (= signals) that arrive after the selected delay 
#### 1.3.2. Length of a single sweep - THIS
The Sweep length is defined by the Range times the Bin Width.
#### 1.3.3. Hold off time (pause time after sweep)- THIS
in steps of 2.56 ns - allows new start only after this additional time has elapsed after the end of the sweep
#### 1.3.4. End of sweep dead-time - THIS
< 50ns
#### 1.3.5. Selection range lmits - THIS
Acq.Delay + TimeRange + Hold-Off ≤ 248 x 2.56 ns = 8.3 days max.



## 2. Tagged spectra acquisiton (p.36)
multi detector experiment: measure which detector has fired (time resolution 5.12ns), still maintain 80 ps bin width



# Measurement Examples
## 3. Pulse width measurement (p.45)
As the edge information is contained in bit 4 of the data (a 1 in that bit means falling edge) it is possible to
distinguish stop events from rising and falling signals and it is possible to analyze the pulse width of the
signals, if Both Edges are chosen. There is a choice between "Over threshold" or "Under threshold" for
the Pulse width analyzing, depending on the corresponding setting in the "inputs" dialog. To see the events
from rising and falling signals separated, just enable Pulse width in the settings dialog and set y-Range to 2
inside the box labeled ”2D spectra”. You will get a two dimensional spectra with a y-dimension of 2, for y=0 it
contains the stop events from rising edges and for y=1 from falling edges. You can see here the separation
time between both edges. If you set then the y-Range to a value larger than the maximum pulse width in
channels, you will get a 2-dimensional spectra with the time of the first edge as x coordinate and the pulse
width as y coordinate (see chapter 2.5.4). (There is more text in the document ...)

# Input Settings

## 4. ROI Preset (p.44)
ROI Preset checkboxes marked: measurement stopped after acquiring more events than specified (events are counted only if they are within the ROI limits, i.e. >= the lower limit and < the upper limit)

## 5. Treshold voltage (p.44) - THIS
+ Fast NIM (-0.3 V) or customized
+ Falling or Rising Edge
+ See "Measurement examples" or document p.45 for pulse width measurement

# Electrical ratings (p.99)

## 6. START / STOP (discriminator) inputs
+ Voltage range       -2.0 … +3.0 V
+ Threshold voltage   -1.0 … +1.5 V
### 6.1. Absolute maximum ratings
+ DC input current            ± 80 mA
+ any discriminator input     -3.0 … +4.0 V

# Notes
## 7. Dark count histogram
### 7.1. Parameter Correspondance
#### 7.1.1. Number of repetions - Sweep preset
#### 7.1.2. Expectation value $\lambda$ - controlle by Time range
Range * bin width

# How to set the settings
## Active channels
+ active = 1
+ and dont forget sweepmode !
## 8. Start event generation (???)
If start event generation is checked, a start event is inserted into the data stream and counted.

## 9. After sweep
### 9.1. Save
+ savedata=1
### 9.2. Auto increment data files
+ autoinc=1 

## 10. Time Settings
### 10.1. Binning (binwidth)
+ bitshift=0              ; LOWORD: Binwidth = 2 ^ (bitshift)
+ calfact=0.400000 * Binwidth (a setting only required to propperly show the histogram in software)
### 10.2. Range (per channel)
+ range=4096 (in steps of 64)
### 10.3. Hold off time
+ holdafter=6.4 (in of 6.4 ns)
### 10.4. Acquisition delay
+ fstchan = 1 ; acquisition delay = fstchan * 6.4ns
+ caloff=6.4 * fstchan ; MPNAT software calibration for shwoing histogram
## 11. Presets
### 11.1. Prena (is HEX!)
+ prena=4              
+                       ; bit 0: realtime preset enabled
                        ; bit 1:
                        ; bit 2: sweep preset enabled
                        ; bit 3: ROI preset enabled
                        ; bit 4: Starts preset enabled
                        ; bit 5: ROI2 preset enabled
                        ; bit 6: ROI3 preset enabled
                        ; bit 7: ROI4 preset enabled
                        ; bit 8: ROI5 preset enabled
                        ; bit 9: ROI6 preset enabled
                        ; bit 10: ROI7 preset enabled
                        ; bit 11: ROI8 preset enabled

Examples
+ prena = 3 : time preset
+ prena = 6 : sweep preset
+ prena = 7 : sweep & time preset 
+ prena = 2 : nothing
### 11.2. Time preset
+ WRONG: rtpreset=20.000; Timepreset (seconds) [from doc]
+ RIHGT: timepreset = 20.000; (seconds) [observed]
### 11.3. Sweep preset
+ swpreset=20000000    